utils

package
v1.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 29, 2025 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Error

func Error(format string, args ...interface{})

Error prints an error message with red color and error emoji

func Highlight

func Highlight(format string, args ...interface{})

Highlight prints a highlighted message with cyan color

func Info

func Info(format string, args ...interface{})

Info prints an informational message with blue color and info emoji

func PrintSection

func PrintSection(title string)

PrintSection prints a section header

func PrintURL

func PrintURL(name, url string)

PrintURL prints a URL with special formatting

func Success

func Success(format string, args ...interface{})

Success prints a success message with green color and checkmark emoji

func Warning

func Warning(format string, args ...interface{})

Warning prints a warning message with yellow color and warning emoji

Types

This section is empty.

Jump to