Documentation
¶
Index ¶
- func Error(format string, args ...interface{})
- func Highlight(format string, args ...interface{})
- func Info(format string, args ...interface{})
- func PrintSection(title string)
- func PrintURL(name, url string)
- func Success(format string, args ...interface{})
- func Warning(format string, args ...interface{})
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Error ¶
func Error(format string, args ...interface{})
Error prints an error message with red color and error emoji
func Highlight ¶
func Highlight(format string, args ...interface{})
Highlight prints a highlighted message with cyan color
func Info ¶
func Info(format string, args ...interface{})
Info prints an informational message with blue color and info emoji
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.